@@ -2,20 +2,17 @@ import colorsys
 import io
 from time import process_time
 
+from rich import box
 from rich.color import Color
-from rich.columns import Columns
 from rich.console import Console, ConsoleOptions, RenderGroup, RenderResult
 from rich.markdown import Markdown
 from rich.measure import Measurement
-from rich.padding import Padding
-from rich.panel import Panel
 from rich.pretty import Pretty
 from rich.segment import Segment
 from rich.style import Style
-from rich.table import Table
 from rich.syntax import Syntax
+from rich.table import Table
 from rich.text import Text
-from rich import box
 
 
 class ColorBox:
@@ -172,9 +169,9 @@ def iter_last(values: Iterable[T]) -> Iterable[Tuple[bool, T]]:
         "foo": [
             3.1427,
             (
-                "Paul Atriedies",
+                "Paul Atreides",
                 "Vladimir Harkonnen",
-                "Thufir Haway",
+                "Thufir Hawat",
             ),
         ],
         "atomic": (False, True, None),
@@ -209,7 +206,11 @@ Supports much of the *markdown*, __syntax__!
 
 
 if __name__ == "__main__":  # pragma: no cover
-    console = Console(file=io.StringIO(), force_terminal=True)
+
+    console = Console(
+        file=io.StringIO(),
+        force_terminal=True,
+    )
     test_card = make_test_card()
 
     # Print once to warm cache
@@ -226,3 +227,51 @@ if __name__ == "__main__":  # pragma: no cover
         print(line)
 
     print(f"rendered in {taken}ms")
+
+    from rich.panel import Panel
+
+    console = Console()
+
+    sponsor_message = Table.grid(padding=1)
+    sponsor_message.add_column(style="green", justify="right")
+    sponsor_message.add_column(no_wrap=True)
+    sponsor_message.add_row(
+        "Sponsor me",
+        "[u blue link=https://github.com/sponsors/willmcgugan]https://github.com/sponsors/willmcgugan",
+    )
+    sponsor_message.add_row(
+        "Buy me a :coffee:",
+        "[u blue link=https://ko-fi.com/willmcgugan]https://ko-fi.com/willmcgugan",
+    )
+    sponsor_message.add_row(
+        "Twitter",
+        "[u blue link=https://twitter.com/willmcgugan]https://twitter.com/willmcgugan",
+    )
+    sponsor_message.add_row(
+        "Blog", "[u blue link=https://www.willmcgugan.com]https://www.willmcgugan.com"
+    )
+
+    intro_message = Text.from_markup(
+        """\
+It takes a lot of time to develop Rich and to provide support.
+
+Consider supporting my work via Github Sponsors (ask your company / organization), or buy me a coffee to say thanks.
+
+- Will McGugan"""
+    )
+
+    message = Table.grid(padding=2)
+    message.add_column()
+    message.add_column(no_wrap=True)
+    message.add_row(intro_message, sponsor_message)
+
+    console.print(
+        Panel.fit(
+            message,
+            box=box.ROUNDED,
+            padding=(1, 2),
+            title="[b red]Thanks for trying out Rich!",
+            border_style="bright_blue",
+        ),
+        justify="center",
+    )
