@@ -17,10 +17,17 @@ class FileProxy(io.TextIOBase):
         self.__buffer: List[str] = []
         self.__ansi_decoder = AnsiDecoder()
 
+    @property
+    def rich_proxied_file(self) -> IO[str]:
+        """Get proxied file."""
+        return self.__file
+
     def __getattr__(self, name: str) -> Any:
         return getattr(self.__file, name)
 
     def write(self, text: str) -> int:
+        if not isinstance(text, str):
+            raise TypeError(f"write() argument must be str, not {type(text).__name__}")
         buffer = self.__buffer
         lines: List[str] = []
         while text:
