@@ -38,11 +38,41 @@ class Measurement(NamedTuple):
             width (int): Maximum desired width.
 
         Returns:
-            RenderableWidth: new RenderableWidth object.
+            Measurement: New Measurement object.
         """
         minimum, maximum = self
         return Measurement(min(minimum, width), min(maximum, width))
 
+    def with_minimum(self, width: int) -> "Measurement":
+        """Get a RenderableWith where the widths are >= width.
+
+        Args:
+            width (int): Minimum desired width.
+
+        Returns:
+            Measurement: New Measurement object.
+        """
+        minimum, maximum = self
+        width = max(0, width)
+        return Measurement(max(minimum, width), max(maximum, width))
+
+    def clamp(self, min_width: int = None, max_width: int = None) -> "Measurement":
+        """Clamp a measurement within the specified range.
+
+        Args:
+            min_width (int): Minimum desired width, or ``None`` for no minimum. Defaults to None.
+            max_width (int): Maximum desired width, or ``None`` for no maximum. Defaults to None.
+
+        Returns:
+            Measurement: New Measurement object.
+        """
+        measurement = self
+        if min_width is not None:
+            measurement = measurement.with_minimum(min_width)
+        if max_width is not None:
+            measurement = measurement.with_maximum(max_width)
+        return measurement
+
     @classmethod
     def get(
         cls, console: "Console", renderable: "RenderableType", max_width: int = None
@@ -61,16 +91,14 @@ class Measurement(NamedTuple):
         Returns:
             Measurement: Measurement object containing range of character widths required to render the object.
         """
-        from rich.console import RichCast
-
         _max_width = console.width if max_width is None else max_width
         if _max_width < 1:
             return Measurement(0, 0)
         if isinstance(renderable, str):
             renderable = console.render_str(renderable)
 
-        if isinstance(renderable, RichCast):
-            renderable = renderable.__rich__()
+        if hasattr(renderable, "__rich__"):
+            renderable = renderable.__rich__()  # type: ignore
 
         if is_renderable(renderable):
             get_console_width = getattr(renderable, "__rich_measure__", None)
